import Vue from 'vue';
import Vuex from 'vuex';
import axios from "axios";
import router from "./router";
import callHub from "./callHub";

Vue.use(Vuex);

let store = new Vuex.Store({
  strict: true,
  state: {
    calls: [],
    error: ""
  },
  mutations: {
    setError(state, msg) {
      state.error = msg;
      if (msg) console.log(`Error: ${msg}`);
    },
    setCalls(state, calls) {
      state.calls = calls;
    },
    removeCall(state, call) {
      state.calls = state.calls.filter(function (c) { return c.id !== call.id; });
    },
    addCall(state, call) {
      state.calls.push(call);
    }
  },
  actions: {
    load({ commit }) {
      axios.get("/api/calls")
        .then(res => {
          let calls = res.data;
          commit("setCalls", calls);
        })
        .catch(() => commit("setError", "Failed to load the calls..."));
    },
    answer({ commit }, call) {
      axios.patch(`/api/calls/${call.id}/answer`)
        .then(() => {
          commit("removeCall", call);
          callHub.client.invoke("CallAnswered", call);
          router.push("/");
        })
        .catch(() => commit("setError", "Failed to mark it as answered"));
    }
  }
});

callHub.client.on("NewCall", (newCall) => {
  store.commit("addCall", newCall);
});

callHub.client.on("CallAnswered", call => {
  store.commit("removeCall", call);
});

callHub.start();

export default store;